resumes

# XMLRésuméLibrary: User Guide

resume | Element Reference | score

## Name

resumes — A collection of one or more résumés

## Synopsis

### Content Model

    (resume*)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None
xmlns | CDATA | `http://xmlresume.sourceforge.net/resume/0.0`
xmlns:xsi | CDATA | `http://www.w3.org/2001/XMLSchema-instance`
xsi:schemaLocation | CDATA | None

## Description

The `resumes` element contains one or more résumés. It could be used, for example, to distribute the résumés of all applicants for a job as a single file.

The formatting of this element is currently undefined.

### Parents

`resumes` may be contained in these elements: None

### Attributes

`id`

  A string used to uniquely identify a group of résumés. The résumés may then be referred to by this identifier.

## Examples

    <resumes id="resumes.tech.titans">
      <resume id="resume.gates">
        <header>
          <name>
            <firstname>Bill</firstname>
            <surname>Gates</surname>
          </name>
        </header>
      </resume>
      <resume id="resume.jobs">
        <header>
          <name>
            <firstname>Steve</firstname>
            <surname>Jobs</surname>
          </name>
        </header>
      </resume>
    </resumes>

resume | Element Reference | score